Enum Error

enum Error

A unified error type for anything returned by a method in the time crate.

This can be used when you either don't know or don't care about the exact error returned. Result<_, time::Error> (or its alias time::Result<_>) will work in these situations.

Variants

ConversionRange(ConversionRange)
ComponentRange(ComponentRange)
DifferentVariant(DifferentVariant)
InvalidVariant(InvalidVariant)

Implementations

impl Debug for Error

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for Error

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Error for Error

fn source(self: &Self) -> Option<&dyn Error + 'static>

impl Freeze for Error

impl From for Error

fn from(err: DifferentVariant) -> Self

impl From for Error

fn from(original: ComponentRange) -> Self

impl From for Error

fn from(err: ConversionRange) -> Self

impl From for Error

fn from(err: InvalidVariant) -> Self

impl RefUnwindSafe for Error

impl Send for Error

impl Sync for Error

impl Unpin for Error

impl UnsafeUnpin for Error

impl UnwindSafe for Error

impl<T> Any for Error

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Error

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Error

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for Error

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToString for Error

fn to_string(self: &Self) -> String

impl<T, U> Into for Error

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Error

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Error

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>