Struct DifferentVariant

struct DifferentVariant

An error type indicating that a TryFrom call failed because the original value was of a different variant.

Implementations

impl Clone for DifferentVariant

fn clone(self: &Self) -> DifferentVariant

impl Copy for DifferentVariant

impl Debug for DifferentVariant

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for DifferentVariant

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for DifferentVariant

impl Error for DifferentVariant

impl Freeze for DifferentVariant

impl PartialEq for DifferentVariant

fn eq(self: &Self, other: &DifferentVariant) -> bool

impl RefUnwindSafe for DifferentVariant

impl Send for DifferentVariant

impl StructuralPartialEq for DifferentVariant

impl Sync for DifferentVariant

impl TryFrom for DifferentVariant

fn try_from(err: Error) -> Result<Self, <Self as >::Error>

impl Unpin for DifferentVariant

impl UnsafeUnpin for DifferentVariant

impl UnwindSafe for DifferentVariant

impl<T> Any for DifferentVariant

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DifferentVariant

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DifferentVariant

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for DifferentVariant

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for DifferentVariant

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for DifferentVariant

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> ToString for DifferentVariant

fn to_string(self: &Self) -> String

impl<T, U> Into for DifferentVariant

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DifferentVariant

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DifferentVariant

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>