#[non_exhaustive]pub struct IsoYearLastTwo { /* private fields */ }Available on crate features
formatting or parsing only.Expand description
Year of the date. Only the last two digits are included, and the ISO week-numbering year is used.
Implementations
Sourceimpl IsoYearLastTwo
impl IsoYearLastTwo
Sourcepub const fn default() -> Self
pub const fn default() -> Self
This function exists since Default::default() cannot be used in a const context.
It may be removed once that becomes possible. As the Default trait is in the
prelude, removing this function in the future will not cause any resolution failures for
the overwhelming majority of users; only users who use #![no_implicit_prelude] will be
affected. As such it will not be considered a breaking change.
Sourceimpl IsoYearLastTwo
impl IsoYearLastTwo
Sourcepub const fn with_padding(self, padding: Padding) -> Self
pub const fn with_padding(self, padding: Padding) -> Self
Set the padding type.