MonthLong

Struct MonthLong 

pub struct MonthLong { /* private fields */ }
Available on crate features formatting or parsing only.
Month of the year using the long form of the month name (e.g. “January”).

Implementations

Source

impl MonthLong

pub const fn default() -> Self

This function exists since Default::default() cannot be used in a const context. It may be removed once that becomes possible. As the Default trait is in the prelude, removing this function in the future will not cause any resolution failures for the overwhelming majority of users; only users who use #![no_implicit_prelude] will be affected. As such it will not be considered a breaking change.

Source

impl MonthLong

pub const fn with_case_sensitive(self, case_sensitive: bool) -> Self

Set whether the value is case sensitive when parsing.