#[non_exhaustive]pub struct UnixTimestamp {
pub precision: UnixTimestampPrecision,
pub sign_is_mandatory: bool,
}UnixTimestampSeconds, UnixTimestampMilliseconds, UnixTimestampMicroseconds, or UnixTimestampNanoseconds insteadformatting or parsing only.Expand description
A Unix timestamp.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.precision: UnixTimestampPrecisionUnixTimestampSeconds, UnixTimestampMilliseconds, UnixTimestampMicroseconds, or UnixTimestampNanoseconds insteadThe precision of the timestamp.
sign_is_mandatory: boolUnixTimestampSeconds, UnixTimestampMilliseconds, UnixTimestampMicroseconds, or UnixTimestampNanoseconds insteadWhether the + sign must be present for a non-negative timestamp.
Implementations
Sourceimpl UnixTimestamp
impl UnixTimestamp
Sourcepub const fn default() -> Self
pub const fn default() -> Self
Creates a modifier that indicates the value represents the number of seconds since the Unix epoch. The sign is not mandatory.
This function exists since Default::default() cannot be used in a const context.
It may be removed once that becomes possible. As the Default trait is in the
prelude, removing this function in the future will not cause any resolution failures for
the overwhelming majority of users; only users who use #![no_implicit_prelude] will be
affected. As such it will not be considered a breaking change.
Sourceimpl UnixTimestamp
impl UnixTimestamp
Sourcepub const fn with_precision(self, precision: UnixTimestampPrecision) -> Self
pub const fn with_precision(self, precision: UnixTimestampPrecision) -> Self
Set the precision of the timestamp.
Sourcepub const fn with_sign_is_mandatory(self, sign_is_mandatory: bool) -> Self
pub const fn with_sign_is_mandatory(self, sign_is_mandatory: bool) -> Self
Set whether the + sign is mandatory for non-negative timestamps.