Module time::request

source ·
Request

To control the timer, a client sends requests to the server and receive back a response. This module contains the request structure as well as trait to read and write a request.

Enums

Traits