Type Alias Result
type Result = Result<T, Error>
An alias for std::result::Result with a generic error from the time crate.
Resulttype Result = Result<T, Error>
An alias for std::result::Result with a generic error from the time crate.