Function days_in_month
const fn days_in_month(month: Month, year: i32) -> u8
Get the number of days in the month of a given year.
# use ;
assert_eq!;
days_in_monthconst fn days_in_month(month: Month, year: i32) -> u8
Get the number of days in the month of a given year.
# use ;
assert_eq!;