Function days_in_year_month
const fn days_in_year_month(year: i32, month: Month) -> u8
Get the number of days in the month of a given year.
#
# use ;
assert_eq!;
days_in_year_monthconst fn days_in_year_month(year: i32, month: Month) -> u8
Get the number of days in the month of a given year.
#
# use ;
assert_eq!;