Crate rasi_default
source ·Expand description
rasi-default
This crate is a reference implementation of the rasi syscalls.
-
The implementations of
Networksyscall andTimersyscall are based onmio; -
The implementation of
Executorsyscall is based onfutures thread pool; -
The implementation of
FileSystemsyscall is a wrapper ofstd::fs.
Modules
- executor
executorThe implementation ofExecutorsyscall. - fs
fsThis mode is a wrapper ofstd::fsthat implementFileSystemtrait. - net
netThe implementation ofNetworksyscall. - A reactor pattern implementation based on
mio::Poll. - time
timeThe implementation ofTimersyscall.
Traits
- This trait defines a method for sequential generation of
tokens