Enum time::format_description::modifier::WeekNumberRepr [−][src]
#[non_exhaustive]
pub enum WeekNumberRepr {
Iso,
Sunday,
Monday,
}This is supported on crate features
formatting or parsing only.Expand description
The representation used for the week number.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Week 1 is the week that contains January 4.
Week 1 begins on the first Sunday of the calendar year.
Week 1 begins on the first Monday of the calendar year.