pub struct FormatDescriptionV3<'a> { /* private fields */ }Available on crate features
formatting or parsing only.Expand description
A complete description of how to format and parse a type.
Both for forwards compatibility and to enable optimizations, this type is deliberately opaque
and cannot be constructed by users of the crate. Instead, it is returned by the
format_description! macro (when version=3 is used) as well as the parse_borrowed and
parse_owned methods.
Implementations
Sourceimpl FormatDescriptionV3<'_>
impl FormatDescriptionV3<'_>
Sourcepub fn to_owned(self) -> FormatDescriptionV3<'static> ⓘ
Available on crate feature alloc only.
pub fn to_owned(self) -> FormatDescriptionV3<'static> ⓘ
alloc only.Convert the format description to an owned version, enabling it to be stored without regard for lifetime.