timestamp!() { /* proc-macro */ }Available on crate feature
macros only.Expand description
Construct a Timestamp with a statically known value.
The resulting expression can be used in const or static declarations.
The syntax accepted by this macro is a timestamp (as an integer or float) or the same as
utc_datetime!.