Response
When a server receives a request, it sends back a response. This module contains the response structure as well as traits to read and write a response.
Enums
- The server response struct.
Traits
- Trait to read a server response.
- Trait to write a response.