pub type Duration = SignedDuration;Expand description
A SignedDuration under its original name.
This type is not currently deprecated, but it likely will be in the future. Use
SignedDuration when writing new code. In the next breaking release, this alias will be
removed.
Aliased Type
pub struct Duration { /* private fields */ }