pub type PrimitiveDateTime = PlainDateTime;Expand description
A PlainDateTime under its original name.
This type is not currently deprecated, but it likely will be in the future. Use
PlainDateTime when writing new code. In the next breaking release, this alias will be
removed.
Aliased Type
pub struct PrimitiveDateTime { /* private fields */ }